# Script to generate plots with DSC data for the ESAFORM2024 paper:
#
#           Polymer-Metal Interactions and Their Effect on
#                Tool-Ply Friction of C/PEKK in Melt
#              Grouve et al. (w.j.b.grouve@utwente.nl)
#
import pandas as pd
import matplotlib.pyplot as plt
import scienceplots
import numpy as np

# Pandas column shorthands
t = "Dwell (min)"
X = "Xc (%)"

# Filenames to load
folder = "../dsc/"
fn_fric = "friction_specimens/doc_friction_specimens.csv"
fn_ar = "as_received/doc_as_received.csv"

# Load data into dataframes
fric = pd.read_csv(folder+fn_fric, header=0)
fric_groups = fric.groupby("Tool")
ar = pd.read_csv(folder+fn_ar, header=0)

#
# Plot degree of crystallinity vs. dwell time for friction specimens
# and a bar graph with the as-received specimen (Figure 4 in the paper)
# ---------------------------------------------------------------------
with plt.style.context(['science', 'no-latex', 'bright']):
    colors = plt.rcParams['axes.prop_cycle'].by_key()['color'][:3]  # plot colors
    fig, ax = plt.subplots(1, 2, figsize=(6.3, 2.5), sharey=False)

    # Bounds based on DSC traces on as-received APC
    ax[0].fill_between(x=[0, 12.5], y1=[30.9, 30.9], y2=[26.7, 26.7], color='gray', alpha=.5)
    ax[0].plot([0, 12.5], [26.7, 26.7], linestyle='--', color='gray')
    ax[0].plot([0, 12.5], [30.9, 30.9], linestyle='--', color='gray')

    # Samples extracted from friction specimens
    for i, (name, group) in enumerate(fric_groups):
        ax[0].plot(group[t], group[X], marker='o', linestyle='', label=name,
                   markerfacecolor=colors[i], markeredgecolor='k', markersize=4,
                   linewidth=1)
    ax[0].set_title(r"Friction specimens", fontsize=9)
    ax[0].set_ylabel(r"Degree of crystallinity, %")
    ax[0].set_xlabel("Dwell time, min.")
    ax[0].set_ylim((0, 35))
    ax[0].set_xlim((0, 12))
    ax[0].set_xticks([2.5, 5, 10])
    ax[0].legend(fontsize=9)

    # As-received materials
    x = np.array([1, 2, 4, 5])
    ax[1].bar([x[0], x[2]], [ar[X][0], ar[X][2]], label="without metal")
    ax[1].bar([x[1], x[3]], [ar[X][1], ar[X][3]], label="with metal")
    ax[1].set_xticks([1.5, 4.5])
    ax[1].set_xticklabels(["APC tape", "PEKK film"])
    ax[1].xaxis.set_ticks_position('none')
    ax[1].set_ylabel("Degree of crystallinity, %")
    ax[1].set_ylim((0, 35))
    ax[1].set_title("As-recieved after 10-minute dwell", fontsize=9)
    ax[1].text(x[0], 2, "without metal", rotation=90, ha="center", color='white')
    ax[1].text(x[1], 2, "with metal", rotation=90, ha="center", color='k')
    ax[1].text(x[2], 2, "without metal", rotation=90, ha="center", color='white')
    ax[1].text(x[3], 2, "with metal", rotation=90, ha="center", color='k')

    fig.subplots_adjust(bottom=0.16, wspace=0.3)
    # plt.savefig("../figures/Fig4_dsc_data.png", dpi=600)
    plt.show(block=False)
