# Script to generate plots with friction data for the ESAFORM2024 paper:
#
#           Polymer-Metal Interactions and Their Effect on
#                Tool-Ply Friction of C/PEKK in Melt
#              Grouve et al. (w.j.b.grouve@utwente.nl)
#
import pandas as pd
import matplotlib.pyplot as plt
import scienceplots
from matplotlib.lines import Line2D

# Pandas column shorthands
F = "Force [N]"
d = "Disp. [mm]"
t = "Time [s]"
τ = "Shear Stress [kPa]"

A = (50E-3)**2  # platen area to calculate shear stress

# Filenames to load
folder = "../friction/"
fn_MS = ["APC_MS_02_1.csv", "APC_MS_02_2.csv", "APC_MS_02_3.csv",
         "APC_MS_05_1.csv", "APC_MS_05_2.csv", "APC_MS_05_3.csv",
         "APC_MS_10_1.csv", "APC_MS_10_2.csv", "APC_MS_10_3.csv"]
fn_MSRC = ["APC_MSRC_02_1.csv", "APC_MSRC_02_2.csv", "APC_MSRC_02_3.csv",
           "APC_MSRC_05_1.csv", "APC_MSRC_05_2.csv", "APC_MSRC_05_3.csv",
           "APC_MSRC_10_1.csv", "APC_MSRC_10_2.csv", "APC_MSRC_10_3.csv"]
fn_PI = ["APC_PI_10_3.csv", "APC_PI_10_2.csv", "APC_PI_10_1.csv",
         "APC_PI_05_3.csv", "APC_PI_05_2.csv", "APC_PI_05_1.csv",
         "APC_PI_02_3.csv", "APC_PI_02_2.csv", "APC_PI_02_1.csv"]
fn_MSf = ["APC_MSfilm_02_1.csv", "APC_MSfilm_02_2.csv", "APC_MSfilm_02_3.csv",
          "APC_MSfilm_05_1.csv", "APC_MSfilm_05_2.csv", "APC_MSfilm_05_3.csv",
          "APC_MSfilm_10_1.csv", "APC_MSfilm_10_2.csv", "APC_MSfilm_10_3.csv"]
fn_SS = ["APC_SS_02_3.csv", "APC_SS_02_2.csv", "APC_SS_02_1.csv",
         "APC_SS_05_3.csv", "APC_SS_05_2.csv", "APC_SS_05_1.csv",
         "APC_SS_10_3.csv", "APC_SS_10_2.csv", "APC_SS_10_1.csv"]

# Load data into a list of pandas dataframes
MS = [pd.read_csv(folder+f, header=0) for f in fn_MS]      # mild steel
MSRC = [pd.read_csv(folder+f, header=0) for f in fn_MSRC]  # release-coated mild steel
PI = [pd.read_csv(folder+f, header=0) for f in fn_PI]      # PI film
MSf = [pd.read_csv(folder+f, header=0) for f in fn_MSf]    # mild steel + PEKK film
SS = [pd.read_csv(folder+f, header=0) for f in fn_SS]      # stainless steel

# Drop data after reaching load limit
for df in MS[6:]:
    df.drop(df.index[360:], inplace=True)

# Calculate shear stress
for df in (MS + MSRC + PI + MSf + SS):
    df[τ] = (df[F]/(2*A)) * 1E-3  # stress in kPa

#
# Plot graphs for MS, MSRC, PI, MSf (Figure 3 in the ESAFORM paper)
# -----------------------------------------------------------------
with plt.style.context(['science', 'no-latex', 'bright']):
    colors = plt.rcParams['axes.prop_cycle'].by_key()['color'][:3]  # plot colors
    fig, ax = plt.subplots(2, 2, figsize=(6.3, 4), sharex=True, sharey=True)
    for i, df in enumerate(MS[:6]):
        df.plot(d, τ, ax=ax[0, 0], label="", color=colors[i//3], legend=None)
    for i, df in enumerate(MS[-3:]):
        df.plot(d, τ, ax=ax[0, 0], label="", color=colors[2], legend=None,
                zorder=5, clip_on=False)
    ax[0, 0].text(5, 140, "a) APC vs. steel", fontsize=9, ha='center')
    ax[0, 0].set_ylabel("Shear stress, kPa")
    ax[0, 0].set_xlim((0, 10))

    for i, df in enumerate(MSRC):
        df.plot(d, τ, ax=ax[0, 1], label="", color=colors[i//3], legend=None)
    ax[0, 1].text(5, 140, "b) APC vs. steel + RC", fontsize=9, ha='center')
    ax[0, 1].set_xlim((0, 10))

    for i, df in enumerate(PI):
        df.plot(d, τ, ax=ax[1, 0], label="", color=colors[i//3], legend=None)
    ax[1, 0].text(5, 140, "c) APC vs. polyimide", fontsize=9, ha='center')
    ax[1, 0].set_xlabel("Displacement, mm")
    ax[1, 0].set_ylabel("Shear stress, kPa")
    ax[1, 0].set_xlim((0, 10))

    for i, df in enumerate(MSf):
        df.plot(d, τ, ax=ax[1, 1], label="", color=colors[i//3], legend=None)
    ax[1, 1].text(5, 140, "d) APC + PEKK film vs. steel", fontsize=9, ha='center')
    ax[1, 1].set_xlabel("Displacement, mm")
    ax[1, 1].set_xlim((0, 10))
    ax[1, 1].set_ylim((0, 160))

    # Legend
    l = [ax[1, 1].get_lines()[i] for i in [0, 3, 6]]
    ax[1, 1].legend(l, ['2.5 min.', '5 min.', '10 min.'], loc='center', fontsize=9)

    # Gap in axes lines to indicate that the stress exceeded force cell capacity
    ax[0, 0].add_patch(plt.Rectangle((1.0, 157), 0.6, 10, facecolor='white',
                                     clip_on=False, linewidth = 0, zorder=3))
    ax[0, 0].plot([1.28, 1.35], [163, 173], color=colors[2], linewidth=1.5,
                  clip_on=False, zorder=4)
    ax[0, 0].text(1.7, 180, "reached load limit", clip_on=False)

    fig.subplots_adjust(bottom=0.1, top=0.9, left=0.1, right=0.95)
    # plt.savefig("../figures/Fig3_friction_data_MS.png", dpi=600)
    plt.show(block=False)

#
# Plot graphs with comparision between MS and SS (Figure 8 of paper)
# ------------------------------------------------------------------
with plt.style.context(['science', 'no-latex', 'bright']):
    colors = plt.rcParams['axes.prop_cycle'].by_key()['color'][:3]  # plot colors
    fig, ax = plt.subplots(1, 1, figsize=(3.5, 2.2))
    for i, df in enumerate(MS[:6]):
        df.plot(d, τ, ax=ax, label="", color=colors[i//3], linestyle='--',
                legend=None)
    for i, df in enumerate(MS[-3:]):
        df.plot(d, τ, ax=ax, label="", color=colors[2], linestyle='--',
                legend=None, zorder=5, clip_on=False)
    for i, df in enumerate(SS):
        df.plot(d, τ, ax=ax, label="", color=colors[i//3], legend=None)
    ax.set_xlabel("Displacement, mm")
    ax.set_ylabel("Shear stress, kPa")
    ax.set_ylim((0, 160))
    ax.set_xlim((0, 10))

    # Legend
    l = [ax.get_lines()[i] for i in [9, 12, 15]]
    l.append(Line2D([0], [0], color='k', linestyle='--'))
    l.append(Line2D([0], [0], color='k'))
    ax.legend(l, ['2.5 min.', '5 min.', '10 min.', 'mild steel', 'stainless steel'],
              loc='upper right', fontsize=9)

    # Gap in axes lines to indicate that the stress exceeded force cell capacity
    ax.add_patch(plt.Rectangle((1.0, 157), 0.6, 10, facecolor='white',
                               clip_on=False, linewidth = 0, zorder=3))
    ax.plot([1.28, 1.35], [163, 173], color=colors[2], linewidth=1.5,
            clip_on=False, zorder=4)
    ax.text(1.7, 180, "reached load limit", clip_on=False)
    fig.subplots_adjust(bottom=0.20, top=0.85, left=0.16)
    # fig.savefig("../figures/Fig8_friction_data_MS_SS.png", dpi=600)
    plt.show(block=False)
